<?php
/**
 * @package   Switips
 * @author    Outcode https://outcode.ru/
 * @license   http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 only
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

class JBCartElementHookSwitipsStatuspaid extends JBCartElementHook{
  
  public $api_url = 'https://staging-backend.switips.com/rest/partner/track';  
  
  /**
   * @param array $params
   * @return bool
   */
  public function hasValue($params = array()){
      return true;
  }
  /**
   * @param array $params
   * @return bool
   */   
  public function notify($params = array()){
    $order = $this->getOrder();
    $uid = $this->getUid($order->id);
    $switips = $this->getSwitipsParams();

    if(is_null($uid)){ return; }
    if(is_null($switips)){ return; }
    if($switips->status_active < 1){ return; }

    $args = [      
      'secret_key' => $switips->secret_key,
      'merchant_id' => $switips->merchant_id,
      'campaign_id' => 0,
      'category_id' => 0,
      'user_id' => $uid['uid'],    
      'transaction_id' => $order->id,
      'transaction_amount' => $order->getTotalSum()->val(),
      'transaction_amount_currency' => $order->getTotalSum()->val(),
      'currency' => strtoupper($order->getCurrency()),      
      'tt_date' => strtotime($order->created),
      'stat' => 'paid', 
      'commission_amount' => $this->getCommission($order),
    ]; 
    
    if($switips->api_url == ''){
      $switips->api_url = $this->api_url;
    }    

    JLoader::register('Switips', JPATH_ROOT . '/libraries/switipsapi/switips.php');    
    $SwitipsCls = new Switips($switips->api_url);    
    $send = $SwitipsCls->sendRequestPost($args); 
	}
  
  public function getUid($order_id){
    $db = JFactory::getDbo();
    $query = $db->getQuery(true);
    $query->select($db->quoteName(['uid']));
    $query->from($db->quoteName('#__switips'));
    $query->where('order_id='.$order_id);
    $db->setQuery($query);

    return $db->loadAssoc();
  } 
  
  public function getSwitipsParams(){
    $db = JFactory::getDbo();
    $query = $db->getQuery(true);
    $query->select($db->quoteName(['params']));
    $query->from($db->quoteName('#__modules'));
    $query->where($db->quoteName('module').'= "mod_switips"');
    $db->setQuery($query);
    
    $params = $db->loadAssoc();
    
    if(!is_null($params)){
      $params = json_decode($params['params']);
    }

    return $params;
  } 

  public function getCommission($order){
    $items = $order->getItems(true);

    $commission = 0;
		foreach($items as $key => $cartItem) {
      $qty = $cartItem->get('quantity', 1);      
      $unit_price = $cartItem->get('variations', 0);      
      $unit_price = isset($unit_price[0]['_value']['value']) ? $unit_price[0]['_value']['value'] : 0;

      $product = $this->app->table->item->get($cartItem['item_id']);
      $element_data = $product->getElementsByType('switips');
      
      $element = array_shift($element_data);
      
      if(is_null($element)){
        continue;
      }
      

      $product_commission = $this->checCommission($element->get('commission', 0));      
      
      if($product_commission > 0){        
        if(strpos($product_commission, '%') !== false){
          $product_commission = str_replace('%', '', $product_commission);
          $product_commission = ($unit_price/100)*$product_commission;          
        }        
      }      
      
      $commission += ($product_commission*$qty);
    }
    
    return $commission;
  } 
  
  public function checCommission($value = 0){
    $pattern = '/[^0-9 %]+/msiu';
    if(preg_match($pattern, $value)){      
      return 0; // Найдены запрещенные символы
    }else{
      return str_replace(' ', '', $value);
    }  
  }  
}
